# blackout.rb
#-----------------------------------------------------------------------------
# Version: 1.2.0
# Compatible: SketchUp 6 & 7
#-----------------------------------------------------------------------------
#
# Turns all materials black
#
#-----------------------------------------------------------------------------
#
# Thomas Thomassen
# thomas[at]thomthom[dot]net
#
#-----------------------------------------------------------------------------

require 'sketchup.rb'

#-----------------------------------------------------------------------------
# Add some menu items to access this
if( not file_loaded?('blackout.rb') )
    plugins_menu = UI.menu('Plugins')
    plugins_menu.add_item('Blackout')				{ Blackout::let_it_be_darkness() }
    plugins_menu.add_item('Mask Object Material')	{ Blackout::mask_selection() }
    plugins_menu.add_item('Mask Current Material')	{ Blackout::mask_current() }
end
#-----------------------------------------------------------------------------
file_loaded('blackout.rb')
#-----------------------------------------------------------------------------

module Blackout
	def self.let_it_be_darkness
		# Make use of the SU7 speed boost with start_operation while
		# making sure it works in SU6.
		if Sketchup.version.split('.')[0].to_i >= 7
			Sketchup.active_model.start_operation('Blackout', true)
		else
			Sketchup.active_model.start_operation('Blackout')
		end
		
		Sketchup.active_model.materials.each { | material |
			material.texture = nil
			material.color = 'Black'
			material.alpha = 1
		}
		
		Sketchup.active_model.commit_operation
	end
	
	def self.mask_selection
		sel = Sketchup.active_model.selection
		if not ( sel.length == 1 && (	sel[0].kind_of?(Sketchup::Edge) ||
										sel[0].kind_of?(Sketchup::Face) ||
										sel[0].kind_of?(Sketchup::Group) ||
										sel[0].kind_of?(Sketchup::ComponentInstance) ) )
			UI.messagebox 'Select only one edge, face, group or component.'
			return
		end
		
		# Make use of the SU7 speed boost with start_operation while
		# making sure it works in SU6.
		if Sketchup.version.split('.')[0].to_i >= 7
			Sketchup.active_model.start_operation('Mask Selection', true)
		else
			Sketchup.active_model.start_operation('Mask Selection')
		end
		
		Sketchup.active_model.materials.each { | material |
			material.texture = nil
			material.color = 'Black'
			material.alpha = 1
		}
		
		# Unmask the material we want
		material = sel[0].material
		material.color = 'White'
		
		Sketchup.active_model.commit_operation
	end
	
	def self.mask_current
		# Make use of the SU7 speed boost with start_operation while
		# making sure it works in SU6.
		if Sketchup.version.split('.')[0].to_i >= 7
			Sketchup.active_model.start_operation('Mask Selection', true)
		else
			Sketchup.active_model.start_operation('Mask Selection')
		end
		
		Sketchup.active_model.materials.each { | material |
			material.texture = nil
			material.color = 'Black'
			material.alpha = 1
		}
		
		# Unmask the material we want
		Sketchup.active_model.materials.current.color = 'White'
		
		Sketchup.active_model.commit_operation
	end
end